diff genetrack.py @ 5:551630d1fae3 draft

Uploaded
author greg
date Sat, 21 Nov 2015 08:57:27 -0500
parents fcc2f5992551
children 1a9f1a4fa36c
line wrap: on
line diff
--- a/genetrack.py	Sat Nov 21 08:57:17 2015 -0500
+++ b/genetrack.py	Sat Nov 21 08:57:27 2015 -0500
@@ -1,13 +1,8 @@
 """
 genetrack.py
 
-Input: either ssccidx or gff format of reads
-.ssccidx format: tab-separated chromosome (chr##), index, + reads, - reads
-.gff format: standard gff, score interpreted as number of reads
-
-Output: Called peaks in either gff or txt format
-.txt format: tab-separated chromosome, strand, start, end, read count
-.gff format: standard gff, score is read count
+Input: either scidx or gff format of reads
+Output: Called peaks in gff format
 """
 import optparse
 import csv
@@ -33,7 +28,7 @@
             # Make sure the reads for each chromosome are sorted by index.
             input_path = genetrack_util.sort_chromosome_reads_by_index(dataset_path)
         else:
             # We're processing ssccidx data.
             input_path = dataset_path
         output_name = 's%se%su%sd%sF%s_on_data_%s' % (str(options.sigma),
                                                       str(options.exclusion),
@@ -33,7 +28,7 @@
             input_path = genetrack_util.sort_chromosome_reads_by_index(dataset_path)
         else:
-            # We're processing ssccidx data.
+            # We're processing scidx data.
             input_path = dataset_path
         output_name = 's%se%su%sd%sF%s_on_data_%s' % (str(options.sigma),